<?php

namespace Milople\Personalizedrich\Block\Adminhtml\Category\Edit\Tab;

use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Grid\Column;
use Magento\Backend\Block\Widget\Grid\Extended;
use Magento\Backend\Helper\Data;
use Magento\Catalog\Model\ResourceModel\Product\CollectionFactory;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Registry;
use Milople\Personalizedrich\Model\ResourceModel\Category;

class Products extends Extended
{
    /**
     * @var CollectionFactory
     */
    private $productCollectionFactory;
    private $attachModel;
    private $contactFactory;
    private $registry;

    public function __construct(
        Context                        $context,
        Data                                   $backendHelper,
        Registry                                    $registry,
        CollectionFactory $productCollectionFactory,
        Category         $category,
        ResourceConnection                      $resourceConnection,
        array                                                          $data = []
    ) {
        $this->productCollectionFactory = $productCollectionFactory;
        $this->registry = $registry;
        $this->category = $category;
        $this->resourceConnection = $resourceConnection;
        parent::__construct($context, $backendHelper, $data);
    }

    /**
     * _construct
     * @return void
     */
    public function _construct()
    {
        parent::_construct();
        $this->setId('products');
        $this->setDefaultSort('entity_id');
        $this->setDefaultDir('DESC');
        $this->setSaveParametersInSession(true);
        $this->setUseAjax(true);
        if ($this->getRequest()->getParam('product_id')) {
            $this->setDefaultFilter(['in_product' => 1]);
        }
    }

    /**
     * @param Column $column
     * @return $this
     */
    public function _addColumnFilterToCollection($column)
    {
        if ($column->getId() == 'in_product') {
            $productIds = $this->_getSelectedProducts();
            if (empty($productIds)) {
                $productIds = 0;
            }
            if ($column->getFilter()->getValue()) {
                $this->getCollection()->addFieldToFilter('entity_id', ['in' => $productIds]);
            } else {
                if ($productIds) {
                    $this->getCollection()->addFieldToFilter('entity_id', ['nin' => $productIds]);
                }
            }
        } else {
            parent::_addColumnFilterToCollection($column);
        }
        return $this;
    }

    public function _getSelectedProducts()
    {
        $categoryId = $this->getRequest()->getParam('category_id');
        $resource = $this->resourceConnection;
        $connection = $resource->getConnection();
        $select = $connection->select()->from(['test' => $this->category->getCategoryProductTable()], ['product_id'])->where('category_id = :category_id');
        $binds = [':category_id' => (int)$categoryId];
        $oldProducts = $connection->fetchAll($select, $binds);
        $result = [];
        foreach ($oldProducts as $i => $k) {
            $result[$k['product_id']] = '';
        }
        $selected = [];
        foreach ($oldProducts as $i => $k) {
            $selected[] = $k['product_id'];
        }
        if (!is_array($selected)) {
            $selected = [];
        }
        return $selected;
    }

    /**
     * prepare collection
     */
    public function _prepareCollection()
    {
        $collection = $this->productCollectionFactory->create();
        $collection->addAttributeToSelect('name');
        $collection->addAttributeToSelect('sku');
        $collection->addAttributeToSelect('price');
        $this->setCollection($collection);
        return parent::_prepareCollection();
    }

    /**
     * @return $this
     */
    public function _prepareColumns()
    {
        $model = $this->attachModel;
        $this->addColumn('in_product', ['header_css_class' => 'a-center', 'type' => 'checkbox', 'name' => 'in_product', 'align' => 'center', 'index' => 'entity_id', 'values' => $this->_getSelectedProducts(),]);
        $this->addColumn('entity_id', ['header' => __('Product ID'), 'type' => 'number', 'index' => 'entity_id', 'header_css_class' => 'col-id', 'column_css_class' => 'col-id',]);
        $this->addColumn('names', ['header' => __('Name'), 'index' => 'name', 'class' => 'xxx', 'width' => '50px',]);
        $this->addColumn('sku', ['header' => __('Sku'), 'index' => 'sku', 'class' => 'xxx', 'width' => '50px',]);
        $this->addColumn('price', ['header' => __('Price'), 'type' => 'currency', 'index' => 'price', 'width' => '50px',]);
        return parent::_prepareColumns();
    }

    /**
     * @return string
     */
    public function getGridUrl()
    {
        return $this->getUrl('*/*/products', ['_current' => true]);
    }

    /**
     * @param object $row
     * @return string
     */
    public function getRowUrl($row)
    {
        return '';
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden()
    {
        return true;
    }
}
