<?php
/**
*
* Do not edit or add to this file if you wish to upgrade the module to newer
* versions in the future. If you wish to customize the module for your
* needs please contact us to https://www.milople.com/contact-us.html
*
* @category    Ecommerce
* @package     Milople_Personlized
* @copyright   Copyright (c) 2016 Milople Technologies Pvt. Ltd. All Rights Reserved.
* @url         https://www.milople.com/magento2-extensions/personalized-products-m2.html
*
**/

namespace Milople\Personalizedrich\Block\Adminhtml\Image\Edit;

use Magento\Backend\Block\Template\Context;
use Magento\Framework\Data\FormFactory;
use Magento\Framework\Registry;
use Magento\Store\Model\System\Store;
use Milople\Personalizedrich\Api\Data\ImageInterface;
use Milople\Personalizedrich\Model\Image\Source\Status;
use Magento\Backend\Block\Widget\Form\Generic;
use Magento\Framework\Data\Form as DataForm;
use Milople\Personalizedrich\Helper\Product\View\Personalized;
class Form extends Generic
{
    
    protected $_formFactory;

    protected $_coreRegistry;

    protected $_personalizedHelper;

    public function __construct(
        Context $context,
        Registry $registry,
        FormFactory $formFactory,
        Store $systemStore,
        Personalized $personalizedHelper,
        array $data = []
    ) {
        $this->_coreRegistry = $registry;
        $this->_formFactory = $formFactory;
        $this->_systemStore = $systemStore;
        $this->_personalizedHelper = $personalizedHelper;
         parent::__construct($context, $registry, $formFactory, $data);
    }
       
    /**
     * Init form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('image_form');
        $this->setTitle(__('Image Information'));
    }

    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
        $model = $this->_coreRegistry->registry('personalized_category_image');

        $enable = $this->_personalizedHelper->getConfig('personalizedrich/Image_setting_group/clipart_price_enabled');

        /** @var DataForm $form */
        $form = $this->_formFactory->create(
            ['data' => ['id' => 'edit_form', 'action' => $this->getData('action'), 'method' => 'post', 'enctype' => 'multipart/form-data']]
        );

        $form->setHtmlIdPrefix('image_');

        $fieldset = $form->addFieldset(
            'base_fieldset',
            ['legend' => __('General Information'), 'class' => 'fieldset-wide']
        );

        if ($model->getId()) {
            $fieldset->addField(
                ImageInterface::ID,
                'hidden',
                ['name' => ImageInterface::ID]
            );
        }

        $fieldset->addField(
            ImageInterface::NAME,
            'text',
            ['name' => ImageInterface::NAME, 'label' => __('Name'), 'title' => __('Name'), 'required' => true]
        );

        if($enable == 1)
        {

        $fieldset->addField(
            ImageInterface::PRICE,
            'text',
            ['name' => ImageInterface::PRICE, 'label' => __('Price'), 'title' => __('Price'), 'required' => false]
        );

        }

        $fieldset->addField(
            ImageInterface::PATH,
            'image',
            ['name' => ImageInterface::PATH, 'label' => __('Image'), 'title' => __('Image'), 'required' => false]
        );


        $fieldset->addField(
            ImageInterface::STATUS,
            'select',
            [
                'label' => __('Status'),
                'title' => __('Status'),
                'name' => ImageInterface::STATUS,
                'required' => true,
                'options' => $model->getAvailableStatuses()
            ]
        );



        if (!$model->getId()) {
            $model->setData('status', Status::ENABLED);
        }

        $form->setValues($model->getData());
        $form->setUseContainer(true);
        $this->setForm($form);

        return parent::_prepareForm();
    }
}