<?php
/**
 *
 * Do not edit or add to this file if you wish to upgrade the module to newer
 * versions in the future. If you wish to customize the module for your
 * needs please contact us to https://www.milople.com/contact-us.html
 *
 * @category    Ecommerce
 * @package     Milople_Personlized
 * @copyright   Copyright (c) 2016 Milople Technologies Pvt. Ltd. All Rights Reserved.
 * @url         https://www.milople.com/magento2-extensions/personalizedrich-products-m2.html
 *
 **/

namespace Milople\Personalizedrich\Block\Adminhtml\Quote\Edit;

use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Form\Generic;
use Magento\Framework\Data\FormFactory;
use Magento\Framework\Registry;
use Magento\Store\Model\System\Store;
use Milople\Personalizedrich\Helper\Product\View\Personalized;

class Form extends Generic
{

    /**
     * @var Store
     */
    protected $_systemStore;

    protected $_category;

    /**
     * @param Context $context
     * @param Registry $registry
     * @param FormFactory $formFactory
     * @param Store $systemStore
     * @param array $data
     */
    public function __construct(
        Context                    $context,
        Registry                                $registry,
        FormFactory                        $formFactory,
        Store                          $systemStore,
        Personalized $category,
        array                                                      $data = []
    ) {
        $this->_systemStore = $systemStore;
        $this->_category = $category;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Init form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('quote_form');
        $this->setTitle(__('Quote Information'));
    }

    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
        $model = $this->_coreRegistry->registry('personalized_quote_quote');

        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create(
            ['data' => ['id' => 'edit_form', 'enctype' => 'multipart/form-data', 'action' => $this->getData('action'), 'method' => 'post']]
        );

        $form->setHtmlIdPrefix('quote_');

        $fieldset = $form->addFieldset(
            'base_fieldset',
            ['legend' => __('Quote Information'), 'class' => 'fieldset-wide']
        );

        if ($model->getId()) {
            $fieldset->addField('quote_id', 'hidden', ['name' => 'quote_id']);
        }

        $fieldset->addField(
            'quote',
            'textarea',
            ['name' => 'quote', 'label' => __('Quote'), 'title' => __('Quote'), 'required' => true]
        );


        $fieldset->addField(
            'quote_category',
            'select',
            [
                'label' => __('Category'),
                'title' => __('Category'),
                'name' => 'quote_category',
                'class' => 'validate-select',
                'required' => true,
                'values' => $this->_category->getQuoteCategoryNames()
            ]
        );


        $fieldset->addField(
            'status',
            'select',
            [
                'label' => __('Status'),
                'title' => __('Status'),
                'name' => 'status',
                'options' => ['1' => __('Enabled'), '0' => __('Disabled')]
            ]
        );

        if (!$model->getId()) {
            $model->setData('status', '1');
        }

        $form->setValues($model->getData());
        $form->setUseContainer(true);
        $this->setForm($form);

        return parent::_prepareForm();
    }
}
