<?php
/**
 *
 * Do not edit or add to this file if you wish to upgrade the module to newer
 * versions in the future. If you wish to customize the module for your
 * needs please contact us to https://www.milople.com/contact-us.html
 *
 * @category    Ecommerce
 * @package     Milople_Personlized
 * @copyright   Copyright (c) 2016 Milople Technologies Pvt. Ltd. All Rights Reserved.
 * @url         https://www.milople.com/magento2-extensions/personalized-products-m2.html
 *
 *
 */

namespace Milople\Personalizedrich\Block\Product\View\Type;

use Magento\Catalog\Block\Product\Context;
use Magento\Catalog\Model\ProductRepository;
use Magento\Catalog\Model\ProductTypes\ConfigInterface;
use Magento\Directory\Model\Currency;
use Magento\Directory\Model\CurrencyFactory;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Image\AdapterFactory;
use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\Template;
use Magento\Store\Model\ScopeInterface;
use Milople\Personalizedrich\Helper\Data;
use Milople\Personalizedrich\Helper\Product\View\Personalized;
use Milople\Personalizedrich\Model\FontsFactory;

class Product extends Template
{
    protected $fontModel;
    protected $_filesystem;
    protected $_imageFactory;
    protected $_productRepository;

    public function __construct(
        Context           $context,
        Data              $data_helper,
        FontsFactory      $fontModel,
        Personalized      $personalized_helper,
        AdapterFactory    $imageFactory,
        ProductRepository $productRepository,
        ConfigInterface   $productTypeConfig,
        CurrencyFactory   $currencyFactory,
        array             $data = []
    )
    {
        $this->data_helper = $data_helper;
        $this->_coreRegistry = $context->getRegistry();
        $this->personalized_helper = $personalized_helper;
        $this->_storeManager = $context->getStoreManager();
        $this->fontModel = $fontModel;
        $this->_filesystem = $context->getFilesystem();
        $this->_imageFactory = $imageFactory;
        $this->_productRepository = $productRepository;
        $this->productTypeConfig = $productTypeConfig;
        $this->_currencyFactory = $currencyFactory;
        parent::__construct($context, $data);
    }

    public function shouldRenderQuantity()
    {
        $p_id = $this->getRequest()->getParam('id');
        $_product = $this->_productRepository->getById($p_id);
        return !$this->productTypeConfig->isProductSet($_product->getTypeId());
    }

    public function isRedirectToCartEnabled()
    {
        return $this->_scopeConfig->getValue('checkout/cart/redirect_to_cart', ScopeInterface::SCOPE_STORE);
    }

    public function getProductById($id)
    {
        return $this->_productRepository->getById($id);
    }

    public function getProduct()
    {
        return $this->_coreRegistry->registry('product');
    }

    public function getFontCollection()
    {
        return $this->fontModel->create()->getCollection()->addFieldToFilter('name', ['neq' => ''])->addFieldToFilter('status', '1');
    }

    public function getFontFolder()
    {
        $mediaUrl = $this->_storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_MEDIA);
        return $mediaUrl . 'fonts/';
    }

    /**
     * @param string $image
     * @param int $width
     * @param int $height
     */
    public function resize($image, $width = null, $height = null)
    {
        $absolutePath = $this->_filesystem->getDirectoryRead(DirectoryList::MEDIA)->getAbsolutePath('catalog/product/') . $image;
        $imageResized = $this->_filesystem->getDirectoryRead(DirectoryList::MEDIA)->getAbsolutePath('personalized/resized/' . $width . '/') . $image;
        /*create image factory... */
        $imageResize = $this->_imageFactory->create();
        $imageResize->open($absolutePath);
        $imageResize->constrainOnly(true);
        $imageResize->keepTransparency(true);
        $imageResize->keepFrame(false);
        $imageResize->keepAspectRatio(false);
        $imageResize->resize($width, $height);
        /*destination folder*/
        $destination = $imageResized;
        /* save image   */
        $imageResize->save($destination);
        $resizedURL = $this->_storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_MEDIA) . 'personalized/resized/' . $width . '/' . $image;
        return $resizedURL;
    }

    /**
     * @param float $fromCurrency
     * @param int $amount
     * @param int $image
     */
    public function currencyConvert($amount, $fromCurrency = null, $toCurrency = null)
    {
        /* return $amount; */
        if (!$fromCurrency) {
            $fromCurrency = $this->_storeManager->getStore()->getBaseCurrency();
        }
        if (!$toCurrency) {
            $toCurrency = $this->_storeManager->getStore()->getCurrentCurrency();
        }
        if (is_string($fromCurrency)) {
            $rateToBase = $this->_currencyFactory->create()->load($fromCurrency)->getAnyRate($this->_storeManager->getStore()->getBaseCurrency()->getCode());
        } elseif ($fromCurrency instanceof Currency) {
            $rateToBase = $fromCurrency->getAnyRate($this->_storeManager->getStore()->getBaseCurrency()->getCode());
        }
        $rateFromBase = $this->_storeManager->getStore()->getBaseCurrency()->getRate($toCurrency);
        if ($rateToBase && $rateFromBase) {
            $amount = $amount * $rateToBase * $rateFromBase;
        } else {
            throw new InputException(__('Please correct the target currency.'));
        }
        return $amount;
    }
}
