<?php
/**
 *
 * Do not edit or add to this file if you wish to upgrade the module to newer
 * versions in the future. If you wish to customize the module for your
 * needs please contact us to https://www.milople.com/contact-us.html
 *
 * @category    Ecommerce
 * @package     Milople_Personlized
 * @copyright   Copyright (c) 2016 Milople Technologies Pvt. Ltd. All Rights Reserved.
 * @url         https://www.milople.com/magento2-extensions/personalized-products-m2.html
 *
 **/

namespace Milople\Personalizedrich\Controller\Adminhtml\Fonts;

use Exception;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Filesystem;
use Magento\MediaStorage\Model\File\UploaderFactory;
use Milople\Personalizedrich\Model\Fonts;
use Psr\Log\LoggerInterface;
use Magento\Backend\Model\Session;
use RuntimeException;
use \AllowDynamicProperties;
#[AllowDynamicProperties]

class Save extends Action
{

    protected $_fileUploaderFactory;

    public function __construct(
        Context         $context,
        Filesystem      $filesystem,
        LoggerInterface $logger,
        UploaderFactory $fileUploaderFactory,
        Session         $session,
        Fonts           $fonts
    )
    {
        $this->filesystem = $filesystem;
        $this->fonts = $fonts;
        $this->session = $session;
        $this->_fileUploaderFactory = $fileUploaderFactory;
        $this->_logger = $logger;
        parent::__construct($context);
    }

    public function execute()
    {
        $ttf_flag = 0;
        $woff_flag = 0;
        $data = $this->getRequest()->getParams();
        if ($data) {
            $model = $this->fonts;
            try {
                $uploader = $this->_fileUploaderFactory->create(['fileId' => 'ttf']);
                if (!empty($uploader)) {
                    $uploader->setAllowedExtensions(['ttf']);
                    $uploader->setAllowRenameFiles(false);
                    $uploader->setFilesDispersion(false);
                    $path = $this->filesystem->getDirectoryRead(DirectoryList::MEDIA)
                        ->getAbsolutePath('fonts/');
                    $resultTTF = $uploader->save($path);
                    $ttf_flag = 1;
                }
                $uploader = $this->_fileUploaderFactory->create(['fileId' => 'woff']);
                if (!empty($uploader)) {
                    $uploader->setAllowedExtensions(['woff']);
                    $uploader->setAllowRenameFiles(false);
                    $uploader->setFilesDispersion(false);
                    $path = $this->filesystem->getDirectoryRead(DirectoryList::MEDIA)
                        ->getAbsolutePath('fonts/');
                    $resultWOFF = $uploader->save($path);
                    $woff_flag = 1;
                }
            } catch (Exception $e) {
                \Magento\Framework\App\ObjectManager::getInstance()->get('Psr\Log\LoggerInterface')->info($e->getMessage());
            }


            $id = $this->getRequest()->getParam('font_id');
            if ($id) {
                $model->load($id);
            }

            $model->setName($data['name']);
            $model->setStatus($data['status']);
            if (!empty($uploader)) {
                if ($ttf_flag) {
                    $model->setTtfname($resultTTF['file']);
                }
                if ($woff_flag) {
                    $model->setWoffname($resultWOFF['file']);
                }
            }
            try {
                $model->save();
                $this->messageManager->addSuccess(__('Font was saved successfully'));
                $this->session->setFormData(false);
                if ($this->getRequest()->getParam('back')) {
                    $this->_redirect('*/*/edit', ['id' => $model->getId(), '_current' => true]);
                    return;
                }
                $this->_redirect('*/*/');
                return;
            } catch (\Magento\Framework\Model\Exception $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (RuntimeException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (Exception $e) {
                $this->messageManager->addException($e, __('Something went wrong while saving the font.'));
            }

            $this->_getSession()->setFormData($data);
            $this->_redirect('*/*/edit', ['font_id' => $this->getRequest()->getParam('font_id')]);
            return;
        }
        $this->_redirect('*/*/');
    }
}
