<?php
/**
 *
 * Do not edit or add to this file if you wish to upgrade the module to newer
 * versions in the future. If you wish to customize the module for your
 * needs please contact us to https://www.milople.com/contact-us.html
 *
 * @category    Ecommerce
 * @package     Milople_Personlized
 * @copyright   Copyright (c) 2016 Milople Technologies Pvt. Ltd. All Rights Reserved.
 * @url         https://www.milople.com/magento2-extensions/personalizedrich-products-m2.html
 *
 **/

namespace Milople\Personalizedrich\Controller\Adminhtml\Quote;

use Magento\Backend\App\Action;
use Magento\Backend\Model\View\Result\Page;
use Magento\Backend\Model\View\Result\Redirect;
use Magento\Framework\Registry;
use Magento\Framework\View\Result\PageFactory;
use Milople\Personalizedrich\Model\Quote;

class Edit extends Action
{
    /**
     * Core registry
     *
     * @var Registry
     */
    protected $_coreRegistry = null;

    /**
     * @var PageFactory
     */
    protected $_resultPageFactory;

    /**
     * @var \Milople\Personalized\Model\Quote
     */
    protected $_model;

    /**
     * @param Action\Context $context
     * @param PageFactory $resultPageFactory
     * @param Registry $registry
     * @param \Milople\Personalized\Model\Quote $model
     */
    public function __construct(
        Action\Context $context,
        PageFactory    $resultPageFactory,
        Registry       $registry,
        Quote          $model
    )
    {
        $this->_resultPageFactory = $resultPageFactory;
        $this->_coreRegistry = $registry;
        $this->_model = $model;
        parent::__construct($context);
    }

    /**
     * Edit Department
     *
     * @return Page|Redirect
     * @SuppressWarnings(PHPMD.NPathComplexity)
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        $model = $this->_model;

        // If you have got an id, it's edition
        if ($id) {
            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager->addError(__('This Quote not exists.'));
                /** \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
                $resultRedirect = $this->resultRedirectFactory->create();

                return $resultRedirect->setPath('*/*/');
            }
        }

        $data = $this->_getSession()->getFormData(true);
        if (!empty($data)) {
            $model->setData($data);
        }

        $this->_coreRegistry->register('personalized_quote_quote', $model);

        /** @var Page $resultPage */
        $resultPage = $this->_initAction();
        $resultPage->addBreadcrumb(
            $id ? __('Edit Quote') : __('New Quote'),
            $id ? __('Edit Quote') : __('New Quote')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('Quote'));
        $resultPage->getConfig()->getTitle()
            ->prepend($model->getId() ? $model->getQuote() : __('New Quote'));

        return $resultPage;
    }

    /**
     * Init actions
     *
     * @return Page
     */
    protected function _initAction()
    {
        // load layout, set active menu and breadcrumbs
        /** @var Page $resultPage */
        $resultPage = $this->_resultPageFactory->create();
        $resultPage->setActiveMenu('Milople_Personalizedrich::quote')
            ->addBreadcrumb(__('Quote'), __('Quote'))
            ->addBreadcrumb(__('Manage Quote'), __('Manage Quote'));
        return $resultPage;
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed()
    {
        return true;
    }
}
