<?php
/**
 *
 * Do not edit or add to this file if you wish to upgrade the module to newer
 * versions in the future. If you wish to customize the module for your
 * needs please contact us to https://www.milople.com/contact-us.html
 *
 * @category    Ecommerce
 * @package     Milople_Personlized
 * @copyright   Copyright (c) 2016 Milople Technologies Pvt. Ltd. All Rights Reserved.
 * @url         https://www.milople.com/magento2-extensions/personalized-products-m2.html
 *
 **/

namespace Milople\Personalizedrich\Model\Observer;

use Magento\Framework\App\RequestInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Json\Helper\Data;
use Magento\Framework\Stdlib\DateTime\TimezoneInterface;
use Milople\Personalizedrich\Helper\Product\View\Personalized;
use Psr\Log\LoggerInterface;
use \AllowDynamicProperties;
#[AllowDynamicProperties]

class SetAdditionalOptions implements ObserverInterface
{

    protected $request;
    protected $jsonHelper;

    public function __construct(
        RequestInterface  $request,
        Personalized      $helper,
        Data              $jsonHelper,
        TimezoneInterface $timezone,
        LoggerInterface   $logger
    )
    {
        $this->_request = $request;
        $this->timezone = $timezone;
        $this->jsonHelper = $jsonHelper;
        $this->_logger = $logger;
        $this->helper = $helper;
    }

    public function execute(Observer $observer)
    {
        /* Check and set information according to your need */
        if ($this->_request->getFullActionName() == 'checkout_cart_add') {/*checking when product is adding to cart*/
            $final_name_number_array = [];
            $product = $observer->getProduct();
            $postdata = $this->_request->getPost();
            $textObjectsData = $postdata['textObjectsData'];
            $name = $postdata['passing_name'];
            $number = $postdata['passing_number'];
            $size = $postdata['passing_size'];

            if($product->getTypeId() == 'bundle')
            {
                $bundle_options_id = $postdata['childProduct'];
                $id =  explode(",",$bundle_options_id);
            }

            if ($postdata['name_label'] || $postdata['number_label'] || $postdata['size_label']) {
                $namelabel = $postdata['name_label'];
                $numberlabel = $postdata['number_label'];
                $sizelabel = $postdata['size_label'];
            } else {
                $namelabel = "Column1";
                $numberlabel = "Column2";
                $sizelabel = "Size Dropdown";
            }
            if ($postdata['name_label'] || $postdata['number_label'] || $postdata['size_label']) {
                $no_of_name_and_number = $postdata['name_number_price'];
                $milople_name = explode(',', $name);
                $milople_number = explode(',', $number);
                $milople_size = explode(',', $size);
            }
            $additionalOptions = [];
            if ((isset($postdata['passing_name']) && $postdata['passing_name'] != '') || (isset($postdata['passing_number']) && $postdata['passing_number'] != '') || (isset($postdata['passing_size']) && $postdata['passing_size'] != '')) {
                for ($i = 0; $i < $no_of_name_and_number; $i++) {
                    $intermediate_name = $milople_name[$i];
                    $intermediate_number = $milople_number[$i];
                    $intermediate_size = $milople_size[$i];
                    $final_name_number_array[$i] = $namelabel . " : " . $intermediate_name . " | " . $numberlabel . " : " . $intermediate_number . " | " . $sizelabel . " : " . $intermediate_size;
                }
                $final_name_number_size = implode("<br>", $final_name_number_array);
                $additionalOptions[] = [
                    'label' => "Name & Number Details",
                    'value' => $final_name_number_size,
                ];
            }
            if ($product->getAllowPersonalization()) {
                if (!$textObjectsData[0] == 0) {
                    $text_objects[] = $this->jsonHelper->jsonDecode($textObjectsData[0]);
                    $text_objects = $text_objects[0]['texts'];
                    $text = [];
                    $font_color = [];
                    $font_family = [];
                    foreach ($text_objects as $data) {
                        array_push($text, $data['text']);
                        array_push($font_color, $data['font_color']);
                        array_push($font_family, $data['font_family']);
                    }
                    $i = 1;
                    foreach ($text as $t) {
                        if($t != 'undefined') {
                            $additionalOptions[] = [
                                'label' => "Text" . $i,
                                'value' => $t
                            ];
                            $additionalOptions[] = [
                                'label' => "Text" . $i . " Font Color",
                                'value' => $font_color[$i - 1]
                            ];
                            $additionalOptions[] = [
                                'label' => "Text" . $i . " Font Family",
                                'value' => $font_family[$i - 1]
                            ];
                            $i++;
                        }
                    }
                }
            }
            if (isset($additionalOptions) && !empty($additionalOptions)) {
                $observer->getProduct()->addCustomOption('additional_options', $this->helper->getSerializedData($additionalOptions));
                if($product->getTypeId() == 'bundle')
                {
                    $observer->getProduct()->addCustomOption('bundle_selection_ids', $this->helper->getSerializedData($id));
                }
            }
        }
    }
}
