<?php

/**
 *
 * Do not edit or add to this file if you wish to upgrade the module to newer
 * versions in the future. If you wish to customize the module for your
 * needs please contact us to https://www.milople.com/contact-us.html
 *
 * @category    Ecommerce
 * @package     Milople_Personlized
 * @copyright   Copyright (c) 2017 Milople Technologies Pvt. Ltd. All Rights Reserved.
 * @url         https://www.milople.com/magento2-extensions/personalized-products-m2.html
 *
 **/

namespace Milople\Personalizedrich\Model;

use Magento\Bundle\Model\Product\Type;
use Magento\Catalog\Model\ProductFactory;
use Magento\Checkout\Model\Cart;
use Magento\Checkout\Model\Session;
use Magento\Directory\Model\Currency;
use Magento\Directory\Model\CurrencyFactory;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Exception;
use Magento\Framework\Filesystem\Io\File;
use Magento\Framework\Registry;
use Magento\Store\Model\StoreManagerInterface;
use Milople\Personalizedrich\Helper\Product\View\Personalized;
use Psr\Log\LoggerInterface;
use \AllowDynamicProperties;
#[AllowDynamicProperties]

class ProcessPersonalized implements ObserverInterface
{
    protected $request;

    public function __construct(
        Registry              $registry,
        RequestInterface      $request,
        ProductFactory        $productModel,
        Session               $checkoutSession,
        Cart                  $cart,
        File                  $filesystem,
        DirectoryList         $directory_list,
        Personalized          $personalized_helper,
        LoggerInterface       $logger,
        StoreManagerInterface $storeManager,
        CurrencyFactory       $currencyFactory
    )
    {
        $this->_registry = $registry;
        $this->_request = $request;
        $this->cart = $cart;
        $this->_productModel = $productModel->create();
        $this->_checkoutSession = $checkoutSession;
        $this->filesystem = $filesystem;
        $this->directory_list = $directory_list;
        $this->_logger = $logger;
        $this->personalized_helper = $personalized_helper;
        $this->_storeManager = $storeManager;
        $this->_currencyFactory = $currencyFactory;
    }

  public function execute(Observer $observer)
  {

    $postdata = $this->_request->getPost();
    $item = $observer->getEvent()->getQuoteItem();
    if (isset($postdata['image_html']) && $postdata['image_html'] != '') {
      try {
        $content = $postdata['image_html'];
        $rawImages = str_replace('"', '', $postdata['raw_images']);
        $product = $this->_productModel->load($postdata['product']);
        $tierPrice = $product->getTierPrice($postdata['qty']);
        $result = $product->addCustomOption('image_html', $content);
        $product->addCustomOption('raw_images', $rawImages);
        $productPrice = $item->getProduct()->getFinalPrice();

        /*Getting price of objects*/
        $pricePerText = $this->personalized_helper
          ->getConfig('personalizedrich/text_setting_group/price_per_text');
        $pricePerImage = $this->personalized_helper
          ->getConfig('personalizedrich/Image_setting_group/personalized_price_per_image');
        $pricePerQuote = $this->personalized_helper
          ->getConfig('personalizedrich/quote_setting/price_per_quote');
        /*Getting object count*/
        $textObjects = $postdata['tObject'];
        $imageObjects = $postdata['iObject'];
        $quoteObjects = $postdata['qObject'];

        /*Getting price of clipart */
        $clipartImgPrice = $postdata['clipartImgPrice'];

        $bundle_price_final = $postdata['bundle_price'];
        $testing_bundle = $item->getProductType();
        $item = ($item->getParentItem() ? $item->getParentItem() : $item);
        if ($testing_bundle == 'bundle') {
          $optionCollection = $product->getTypeInstance()->getOptionsCollection($item->getProduct());
          $selectionCollection = $product->getTypeInstance()->getSelectionsCollection($product->getTypeInstance()->getOptionsIds($item->getProduct()), $item->getProduct());
          $options = $optionCollection->appendSelections($selectionCollection);
          $single_product_of_bundle = NULL;
          $product_simple = NULL;
          $items = $this->cart->getQuote()->getAllItems();
          $size_of_items = sizeof($items) - 1;
          $per_item_price = ($bundle_price_final + ($pricePerText * $textObjects) + ($pricePerImage * $imageObjects) + ($pricePerQuote * $quoteObjects)) / $size_of_items;
          foreach ($items as $i) {
            if ($i->getId() == '')  /*Dont getting id for currently adding bundle item.*/
            {
              $options = $i->getOptions();
              $price = $per_item_price;
              $price = $this->currencyConvert($price);
              $i->setCustomPrice($price);
              $i->setOriginalCustomPrice($price);
            }
          }
          $price = $this->currencyConvert($price);
          $price = ($bundle_price_final + $clipartImgPrice + ($pricePerText * $textObjects) + ($pricePerImage * $imageObjects) + ($pricePerQuote * $quoteObjects)); /*set your price here*/
          $item->setCustomPrice($price);
          $item->setOriginalCustomPrice($price);
        } else {
          if ($tierPrice > 0) {
            $productPrice = min($productPrice, $tierPrice);
          }
          $price = ($productPrice + $clipartImgPrice + ($pricePerText * $textObjects) + ($pricePerImage * $imageObjects) + ($pricePerQuote * $quoteObjects)); 
          /*set your price here*/
          $this->_logger->debug('Price (Before Converting): ' . $price);
          $convertedPrice = $this->currencyConvert($price);
          $this->_logger->debug('Price (After Converting): ' . $convertedPrice);
          $item->setCustomPrice($convertedPrice);
          $item->setOriginalCustomPrice($convertedPrice);
        }
        $item->getProduct()->setIsSuperMode(true);
      } catch (Exception $e) {
        return $e->getMessage();
      }
    }
  }

  public function currencyConvert($amount, $fromCurrency = null, $toCurrency = null)
    {
        /*return $amount;*/
        if (!$fromCurrency) {
            $fromCurrency = $this->_storeManager->getStore()->getBaseCurrency();
        }

        if (!$toCurrency) {
            $toCurrency = $this->_storeManager->getStore()->getCurrentCurrency();
        }

        if (is_string($fromCurrency)) {
            $rateToBase = $this->_currencyFactory->create()->load($fromCurrency)->getAnyRate($this->_storeManager->getStore()->getBaseCurrency()->getCode());
        } elseif ($fromCurrency instanceof Currency) {
            $rateToBase = $fromCurrency->getAnyRate($this->_storeManager->getStore()->getBaseCurrency()->getCode());
        }

        $rateFromBase = $this->_storeManager->getStore()->getBaseCurrency()->getRate($toCurrency);

        if ($rateToBase && $rateFromBase) {
            $amount = $amount * $rateToBase * $rateFromBase;
        } else {
            throw new InputException(__('Please correct the target currency.'));
        }

        return $amount;
    }
}
