<?php

/**
 *
 * Do not edit or add to this file if you wish to upgrade the module to newer
 * versions in the future. If you wish to customize the module for your
 * needs please contact us to https://www.milople.com/contact-us.html
 *
 * @category    Ecommerce
 * @package     Milople_Personlized
 * @copyright   Copyright (c) 2017 Milople Technologies Pvt. Ltd. All Rights Reserved.
 * @url         https://www.milople.com/magento2-extensions/personalized-products-m2.html
 *
 **/

namespace Milople\Personalizedrich\Plugin;

use Magento\Checkout\Model\Cart;
use Magento\Directory\Controller\Currency\SwitchAction;
use Magento\Directory\Model\Currency;
use Magento\Directory\Model\CurrencyFactory;
use Magento\Framework\App\RequestInterface;
use Magento\Store\Model\StoreManagerInterface;
use Psr\Log\LoggerInterface;

class CustomPriceCurrencyChange extends SwitchAction
{
    protected $_storeManager;

    public function __construct(
        StoreManagerInterface $storeManager,
        RequestInterface      $request,
        Cart                  $cart,
        CurrencyFactory       $currencyFactory,
        LoggerInterface       $logger
    )
    {
        $this->_storeManager = $storeManager;
        $this->_logger = $logger;
        $this->_request = $request;
        $this->_cart = $cart;
        $this->_currencyFactory = $currencyFactory;
    }

    /**
     * @return void
     */
    public function beforeExecute(
        $result
    )
    {
        $currentCurrency = $this->_storeManager->getStore()->getCurrentCurrencyCode();

        /** @var StoreManagerInterface $storeManager */
        $currency = (string)$this->_request->getParam('currency');

        $quote = $this->_cart->getQuote();
        $baseCurrencyCode = $this->_storeManager->getStore()->getBaseCurrencyCode();
        $quoteItems = $quote->getItemsCollection();

        foreach ($quoteItems as $item) {

            if ($customPrice = $item->getCustomPrice()) {
                $originalCustomPrice = $item->getOriginalCustomPrice();

                if ($baseCurrencyCode == $currency || $baseCurrencyCode == $currentCurrency) {
                    $customPrice = $this->convertPrice($customPrice, $currentCurrency, $currency);
                    $originalCustomPrice = $this->convertPrice($originalCustomPrice, $currentCurrency, $currency);
                } else {
                    $customPrice = $this->convertAnyCurrencies($customPrice, $baseCurrencyCode, $currentCurrency, $currency);
                    $originalCustomPrice = $this->convertAnyCurrencies($originalCustomPrice, $baseCurrencyCode, $currentCurrency, $currency);
                }

                $item->setCustomPrice(
                    $customPrice
                );
                $item->setOriginalCustomPrice(
                    $originalCustomPrice
                );
                $item->save();
            }
        }
    }

    public function convertPrice($price, $currencyCodeFrom, $currencyCodeTo)
    {
        $currency = $this->_currencyFactory->create()->load($currencyCodeFrom);
        $rate = $currency->getAnyRate($currencyCodeTo);

        $convertedPrice = $price * $rate;

        return $convertedPrice;
    }

    public function convertAnyCurrencies($price, $baseCurrencyCode, $currencyCodeFrom, $currencyCodeTo)
    {
        $currency = $this->_currencyFactory->create()->load($currencyCodeFrom);
        $rate = $currency->getAnyRate($baseCurrencyCode);
        $convertedPrice = $price * $rate;

        $currency = $this->_currencyFactory->create()->load($baseCurrencyCode);
        $rate = $currency->getAnyRate($currencyCodeTo);
        $convertedPrice = $convertedPrice * $rate;

        return $convertedPrice;
    }
}
